# Copyright 2015-2017 VMware, Inc.
# All rights reserved. -- VMware Confidential

"""Exception raising and handling

WARNING: This module is used by the ESX build, so it MUST remain compatible
with both python2 and python3.
"""

class DebugInfoMixIn(object):
   """Mixin to extend exception objects with extra debug information.
   """
   _errType = "Unknown exception"

   def __init__(self, errMsg):
      super(DebugInfoMixIn, self).__init__()
      self._debugInfo = []
      self.addDebugInfo('error', errMsg)

   def addDebugInfo(self, name, desc):
      """Add a debug report entry.
      """
      self._debugInfo.append((name, desc))

   def __str__(self):
      """Return a detailed debug report for this exception.
      """
      errStr = "%s\n" % self._errType
      for name, desc in self._debugInfo:
         errStr += "  %s: %s\n" % (name, str(desc))
      return errStr
