# Copyright 2018 VMware, Inc. All rights reserved. -- VMware Confidential

"""MIME (Multipurpose Internet Mail Extensions)

Per RFC1341: https://tools.ietf.org/html/rfc1341
"""

class MimeContentType(str):
   """String object that represents a MIME Content-Type header field.
   """

   def __new__(cls, value, *args, **kwargs):
      DEFAULT_CONTENT_TYPE = "text/plain;charset=us-ascii"

      if value == "":
         value = DEFAULT_CONTENT_TYPE

      fields = value.split(';')

      typeField = fields.pop(0).lower()
      cls.contentType, _, cls.contentSubtype = typeField.partition('/')
      if not cls.contentType or not cls.contentSubtype:
         raise ValueError("invalid Content-Type value: '%s'" % typeField)

      cls.parameters = {}
      if fields:
         for parameter in fields:
            name, _, val = parameter.partition('=')
            if not name or not val:
               raise ValueError("invalid Content-Type parameter format: '%s'" %
                                parameter)

            cls.parameters[name.lower()] = val

      return str.__new__(cls, value, *args, **kwargs)

   @property
   def charset(self):
      """Encoding charset for this Content-Type.
      """
      try:
         return self.parameters['charset']
      except KeyError:
         raise AttributeError("missing 'charset' parameter in Content-Type: %s"
                              % self)
