# Copyright 2018 VMware, Inc.  All rights reserved. -- VMware Confidential

"""Functionality related to waiting for events to happen."""

from datetime import (
   datetime,
   timedelta,
)
from time import (
   sleep,
)


def waitFor(func, timeout=timedelta(seconds=1),
            interval=timedelta(milliseconds=100)):
   """Repeatedly call a function until it returns true or a timeout is exceeded.

      An exceeded timeout is signaled through a `TimeoutError`.
   """
   end = datetime.now() + timeout
   while datetime.now() < end:
      if func():
         return

      sleep(interval.total_seconds())

   raise TimeoutError("Timeout %s exceeded" % timeout)
