"""Stateful session

This controls the installation process by receiving necessary data from
statefullhost.
"""

from .session import EsxSession

from .statefulhost import (
   ESX_INSTALLATION_START,
   ESX_INSTALLATION_DONE,
   BOOT_FROM_DISK_SUCCESSFUL,
)

class StatefulSession(EsxSession):

   def _onStatusChangeCB(self, host, status):
      """This callback handles status changes to re-direct boot order

      @param host: Host object from statefulhost
      @param status: Current status of ESX session updated by statefulhost
      """
      if super()._onStatusChangeCB(host, status):
         pass

      elif status == ESX_INSTALLATION_START:
         self._logger.info("ESX Installation Start")

      elif status == ESX_INSTALLATION_DONE:
         self._logger.info("ESX Installation Done")
         self._logger.info("Setting boot from hard drive...")
         self._host.setDiskBoot()
         self._host.reset()

      elif status == BOOT_FROM_DISK_SUCCESSFUL:
         self._logger.info("Reboot from disk successful...")
         super()._onEsxInitializedCB()
