# Copyright 2017 VMware, Inc.  All rights reserved. -- VMware Confidential

"""Utilities for inspecting Linux /proc nodes.

   https://www.kernel.org/doc/Documentation/filesystems/proc.txt
"""

import borautils.logparser

class ProcStatParser(borautils.logparser.LogParser):
   """Utility for parser /proc/stat.
   """

   CPU_TIMES_RE = (
      r'(?P<user>\d+)\s+'
      r'(?P<nice>\d+)\s+'
      r'(?P<system>\d+)\s+'
      r'(?P<idle>\d+)\s+'
      r'(?P<iowait>\d+)\s+'
      r'(?P<irq>\d+)\s+'
      r'(?P<softirq>\d+)\s+'
      r'(?P<steal>\d+)\s+'
      r'.*$'
   )

   RULES = {
      'cpu':   r'cpu\s+' + CPU_TIMES_RE,
      'cpu_n': r'cpu(?P<num>\d+)\s+' + CPU_TIMES_RE,
   }

   def __init__(self, *args, **kwargs):
      super().__init__(*args, **kwargs)
      self.AddRules(self.RULES)


if __name__ == '__main__':
   contents ="""
   cpu  102 208 3569 2498047 1035 0 25 138054 0 0
   cpu0 16 25 452 312033 153 0 16 36758 0 0
   cpu1 17 26 430 312188 105 0 3 14600 0 0
   cpu2 12 24 452 312262 99 0 0 14495 0 0
   cpu3 16 28 441 312344 172 0 1 14750 0 0
   cpu4 11 20 424 312518 136 0 0 14243 0 0
   cpu5 11 28 481 311984 120 0 1 14614 0 0
   cpu6 7 28 428 312456 160 0 0 14367 0 0
   cpu7 10 27 458 312259 89 0 0 14224 0 0
   ctxt 164880
   btime 1501625191
   processes 675
   """
   print('Running basic tests ...')
   match = ProcStatParser().ParseString(contents)
   m = next(match)
   assert (m.name == 'cpu' and
           m.groups['user'] == '102' and
           m.groups['steal'] == '138054'), m
   for i in range(4):
      m = next(match)
   assert (m.name == 'cpu_n' and
           m.groups['num'] == '3' and
           m.groups['system'] == '441'), m
   print('OK')

# vim: sw=3 ts=3
