########################################################################
# Copyright 2018 VMware, Inc. All rights reserved.
# -- VMware Confidential
########################################################################

from contextlib import (
   contextmanager,
)
from os import (
   pardir,
)
from os.path import (
   abspath,
   dirname,
   join,
)
from unittest import (
   TestCase,
)
import sys
sys.path.append(abspath(join(dirname(__file__), pardir)))
# We star import the entire module such that other test cases don't have
# to do the whole shebang again.
from redfish import *


class RedFishClientTestCase(TestCase):
   """A base test case for tests using a RedFishClient."""
   host = None
   port = None
   allowUnsecure = True
   username = None
   password = None
   certificate = None


   @contextmanager
   def client(self):
      """Create a RedFishClient object."""
      self.assertIsNotNone(RedFishClientTestCase.host)
      # Note that the port, username, password, and certificate are not obligatory.

      with Client(RedFishClientTestCase.host,
                  port=RedFishClientTestCase.port,
                  allowUnsecure=RedFishClientTestCase.allowUnsecure,
                  username=RedFishClientTestCase.username,
                  password=RedFishClientTestCase.password,
                  certificate=RedFishClientTestCase.certificate,
                  _noSecurityCheck=True) as client:
         yield client


   def testResourcePatch(self):
      """Verify that we can patch a resource."""
      with self.client() as client:
         targets = ["None", "Pxe", "Hdd"]
         system = client.root.Systems.Members[0]
         currentTarget = system.Boot.BootSourceOverrideTarget
         newTarget = targets[(targets.index(currentTarget) + 1) % len(targets)]

         # Note that the Dell system requires us to not specify the same
         # mode that is already set.

         client.root.Systems.Members[0] = {
            "Boot": {
               "BootSourceOverrideTarget": newTarget,
            }
         }

         system = client.root.Systems.Members[0]
         self.assertEqual(system.Boot.BootSourceOverrideTarget, newTarget)
