// Copyright 2018 VMware, Inc. All rights reserved. -- VMware Confidential

package waitFor

import (
	"errors"
	"time"
)

var (
	ErrTimedout = errors.New("Timedout")
)

// WaitFor waits up to `timeout` for the `function` function to return
// true without an error. If an error is returned by the function, it
// returns the error immediately. Otherwise, it continues to retry until the
// timeout is exhausted. Retries will be performed every `interval`.
func WaitFor(function func() (bool, error),
	timeout time.Duration,
	interval time.Duration) error {

	deadline := time.Now().Add(timeout)
	for {

		result, err := function()
		if err != nil {
			return err
		}

		if result {
			return nil
		}

		if time.Now().After(deadline) {
			return ErrTimedout
		}
		time.Sleep(interval)
	}
}
